@@ -6,10 +6,9 @@ import textwrap
 from typing import Any, Dict, List, Optional, Pattern, Tuple, Union
 
 import rich_click as click
-from rich.markdown import Markdown
 
 from robotidy.app import Robotidy
-from robotidy.console import console
+from robotidy.rich_console import console
 from robotidy.decorators import catch_exceptions
 from robotidy.files import DEFAULT_EXCLUDES, find_and_read_config, read_pyproject_config
 from robotidy.transformers import load_transformers
@@ -23,8 +22,14 @@ from robotidy.utils import (
 from robotidy.version import __version__
 
 
-COLOR_SYSTEM = "auto"
+click.rich_click.USE_RICH_MARKUP = True
 click.rich_click.USE_MARKDOWN = True
+click.rich_click.STYLE_OPTION = "bold sky_blue3"
+click.rich_click.STYLE_SWITCH = "bold sky_blue3"
+click.rich_click.STYLE_METAVAR = "bold white"
+click.rich_click.STYLE_OPTION_DEFAULT = "grey37"
+click.rich_click.STYLE_OPTIONS_PANEL_BORDER = "grey66"
+click.rich_click.STYLE_USAGE = "magenta"
 click.rich_click.OPTION_GROUPS = {
     "robotidy": [
         {
@@ -45,9 +50,17 @@ click.rich_click.OPTION_GROUPS = {
         },
         {
             "name": "Global formatting settings",
-            "options": ["--spacecount", "--line-length", "--lineseparator", "--separator", "--startline", "--endline"],
+            "options": [
+                "--spacecount",
+                "--indent",
+                "--line-length",
+                "--lineseparator",
+                "--separator",
+                "--startline",
+                "--endline",
+            ],
         },
-        {"name": "File exclusion", "options": ["--exclude", "--extend-exclude"]},
+        {"name": "File exclusion", "options": ["--exclude", "--extend-exclude", "--skip-gitignore"]},
         {
             "name": "Other",
             "options": ["--target-version", "--verbose", "--color", "--output", "--version", "--help"],
@@ -55,44 +68,8 @@ click.rich_click.OPTION_GROUPS = {
     ],
 }
 
+
 CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
-HELP_MSG = f"""
-Version: {__version__}
-
-Robotidy is a tool for formatting Robot Framework source code.
-See examples at the end of this help message too see how you can use Robotidy.
-Full documentation available at https://robotidy.readthedocs.io .
-"""
-EPILOG = """
-Examples:\n\n
-# Format `path/to/src.robot` file\n
-$ robotidy path/to/src.robot
-
-
-# Format every Robot Framework file inside `dir_name` directory
-
-$ robotidy dir_name
-
-
-# List available transformers:
-
-$ robotidy --list
-
-
-# Display transformer documentation
-
-$ robotidy --desc <TRANSFORMER_NAME>
-
-
-# Format `src.robot` file using `SplitTooLongLine` transformer only
-
-$ robotidy --transform SplitTooLongLine src.robot
-
-
-# Format `src.robot` file using `SplitTooLongLine` transformer only and configured line length 140
-
-$ robotidy --transform SplitTooLongLine:line_length=140 src.robot
-"""
 
 
 class TransformType(click.ParamType):
@@ -173,6 +150,8 @@ def validate_regex(value: Optional[str]) -> Optional[Pattern]:
 
 
 def print_transformer_docs(name, transformer):
+    from rich.markdown import Markdown
+
     documentation = f"## Transformer {name}\n" + textwrap.dedent(transformer.__doc__)
     documentation += f"\nSee <https://robotidy.readthedocs.io/en/latest/transformers/{name}.html> for more examples."
     md = Markdown(documentation, code_theme="native", inline_code_lexer="robotframework")
@@ -219,14 +198,14 @@ def print_transformers_list(target_version: int):
     )
 
 
-@click.command(context_settings=CONTEXT_SETTINGS)  # epilog=EPILOG,
+@click.command(context_settings=CONTEXT_SETTINGS)
 @click.option(
     "--transform",
     "-t",
     type=TransformType(),
     multiple=True,
     metavar="TRANSFORMER_NAME",
-    help="Transform files from [PATH(S)] with given transformer",
+    help="Transform files from \[PATH(S)] with given transformer",
 )
 @click.option(
     "--configure",
@@ -251,7 +230,7 @@ def print_transformers_list(target_version: int):
         "A regular expression that matches files and directories that should be"
         " excluded on recursive searches. An empty value means no paths are excluded."
         " Use forward slashes for directories on all platforms."
-        f" [default: '{DEFAULT_EXCLUDES}']"
+        f" \[default: '{DEFAULT_EXCLUDES}']"
     ),
     show_default=False,
 )
@@ -260,10 +239,16 @@ def print_transformers_list(target_version: int):
     type=str,
     callback=validate_regex_callback,
     help=(
-        "Like --exclude, but adds additional files and directories on top of the"
+        "Like **--exclude**, but adds additional files and directories on top of the"
         " excluded ones. (Useful if you simply want to add to the default)"
     ),
 )
+@click.option(
+    "--skip-gitignore",
+    is_flag=True,
+    show_default=True,
+    help="Skip **.gitignore** files and do not ignore files listed inside.",
+)
 @click.option(
     "--config",
     type=click.Path(
@@ -308,28 +293,38 @@ def print_transformers_list(target_version: int):
     "--spacecount",
     type=click.types.INT,
     default=4,
-    help="The number of spaces between cells in the plain text format.\n",
+    help="The number of spaces between cells",
     show_default=True,
 )
+@click.option(
+    "--indent",
+    type=click.types.INT,
+    default=None,
+    help="The number of spaces to be used as indentation [default: same as --spacecount value]",
+)
 @click.option(
     "-ls",
     "--lineseparator",
     type=click.types.Choice(["native", "windows", "unix", "auto"]),
     default="native",
-    help="Line separator to use in outputs.\n"
-    "native:  use operating system's native line endings\n"
-    "windows: use Windows line endings (CRLF)\n"
-    "unix:    use Unix line endings (LF)\n"
-    "auto:    maintain existing line endings (uses what's used in the first line)",
+    help="""
+    Line separator to use in the outputs:
+    - **native**:  use operating system's native line endings
+    - windows: use Windows line endings (CRLF)
+    - unix:    use Unix line endings (LF)
+    - auto:    maintain existing line endings (uses what's used in the first line)
+    """,
     show_default=True,
 )
 @click.option(
     "--separator",
     type=click.types.Choice(["space", "tab"]),
     default="space",
-    help="Token separator to use in outputs.\n"
-    "space:   use --spacecount spaces to separate tokens\n"
-    "tab:     use a single tabulation to separate tokens\n",
+    help="""
+    Token separator to use in the outputs:
+    - **space**:   use --spacecount spaces to separate tokens
+    - tab:     use a single tabulation to separate tokens
+    """,
     show_default=True,
 )
 @click.option(
@@ -337,7 +332,7 @@ def print_transformers_list(target_version: int):
     "--startline",
     default=None,
     type=int,
-    help="Limit robotidy only to selected area. If --endline is not provided, format text only at --startline. "
+    help="Limit robotidy only to selected area. If **--endline** is not provided, format text only at **--startline**. "
     "Line numbers start from 1.",
     show_default=True,
 )
@@ -346,7 +341,7 @@ def print_transformers_list(target_version: int):
     "--endline",
     default=None,
     type=int,
-    help="Limit robotidy only to selected area. " "Line numbers start from 1.",
+    help="Limit robotidy only to selected area. Line numbers start from 1.",
     show_default=True,
 )
 @click.option(
@@ -389,7 +384,7 @@ def print_transformers_list(target_version: int):
     "-t",
     type=click.Choice([v.name.lower() for v in TargetVersion], case_sensitive=False),
     callback=validate_target_version,
-    help="Only enable transformers supported in set target version. [default: installed Robot Framework version]",
+    help="Only enable transformers supported in set target version. \[default: installed Robot Framework version]",
 )
 @click.version_option(version=__version__, prog_name="robotidy")
 @click.pass_context
@@ -401,11 +396,13 @@ def cli(
     src: Tuple[str, ...],
     exclude: Optional[Pattern],
     extend_exclude: Optional[Pattern],
+    skip_gitignore: bool,
     overwrite: bool,
     diff: bool,
     color: bool,
     check: bool,
     spacecount: int,
+    indent: Optional[int],
     lineseparator: str,
     verbose: bool,
     config: Optional[str],
@@ -421,9 +418,7 @@ def cli(
 ):
     """
     Robotidy is a tool for formatting Robot Framework source code.
-
-    See examples at the end of this help message too see how you can use Robotidy.
-    Full documentation available at https://robotidy.readthedocs.io .
+    Full documentation available at <https://robotidy.readthedocs.io> .
     """
     if list:
         print_transformers_list(target_version)
@@ -448,11 +443,15 @@ def cli(
         # None is default, with check not set -> overwrite, with check set -> overwrite only when overwrite flag is set
         overwrite = not check
 
+    if indent is None:
+        indent = spacecount
+
     if color:
         color = "NO_COLOR" not in os.environ
 
     formatting_config = GlobalFormattingConfig(
         space_count=spacecount,
+        indent=indent,
         line_sep=lineseparator,
         start_line=startline,
         separator=separator,
@@ -465,6 +464,7 @@ def cli(
         src=src,
         exclude=exclude,
         extend_exclude=extend_exclude,
+        skip_gitignore=skip_gitignore,
         overwrite=overwrite,
         show_diff=diff,
         formatting_config=formatting_config,
