@@ -1,8 +1,10 @@
-import re
 import ast
+import re
 from collections import Counter
 
-from robot.api.parsing import ModelTransformer, Variable, Token
+from robot.api.parsing import ModelTransformer, Token, Variable
+
+from robotidy.disablers import skip_if_disabled, skip_section_if_disabled
 from robotidy.exceptions import InvalidParameterValueError
 
 
@@ -16,43 +18,45 @@ class NormalizeAssignments(ModelTransformer):
 
     In this code most common is no equal sign at all. We should remove `=` signs from all lines:
 
-        *** Variables ***
-        ${var} =  ${1}
-        @{list}  a
-        ...  b
-        ...  c
+    ```robotframework
+    *** Variables ***
+    ${var} =  ${1}
+    @{list}  a
+    ...  b
+    ...  c
 
-        ${variable}=  10
+    ${variable}=  10
 
 
-        *** Keywords ***
-        Keyword
-            ${var}  Keyword1
-            ${var}   Keyword2
-            ${var}=    Keyword
+    *** Keywords ***
+    Keyword
+        ${var}  Keyword1
+        ${var}   Keyword2
+        ${var}=    Keyword
+    ```
 
     To:
 
-        *** Variables ***
-        ${var}  ${1}
-        @{list}  a
-        ...  b
-        ...  c
+    ```robotframework
+    *** Variables ***
+    ${var}  ${1}
+    @{list}  a
+    ...  b
+    ...  c
 
-        ${variable}  10
+    ${variable}  10
 
 
-        *** Keywords ***
-        Keyword
-            ${var}  Keyword1
-            ${var}   Keyword2
-            ${var}    Keyword
+    *** Keywords ***
+    Keyword
+        ${var}  Keyword1
+        ${var}   Keyword2
+        ${var}    Keyword
+    ```
 
     You can configure that behaviour to automatically add desired equal sign with `equal_sign_type`
     (default `autodetect`) and `equal_sign_type_variables` (default `remove`) parameters.
     (possible types are: `autodetect`, `remove`, `equal_sign` ('='), `space_and_equal_sign` (' =').
-
-    See https://robotidy.readthedocs.io/en/latest/transformers/NormalizeAssignments.html for more examples.
     """
 
     def __init__(
@@ -101,6 +105,11 @@ class NormalizeAssignments(ModelTransformer):
         self.file_equal_sign_type = None
         self.file_equal_sign_type_variables = None
 
+    @skip_section_if_disabled
+    def visit_Section(self, node):  # noqa
+        return self.generic_visit(node)
+
+    @skip_if_disabled
     def visit_KeywordCall(self, node):  # noqa
         if node.assign:  # if keyword returns any value
             assign_tokens = node.get_tokens(Token.ASSIGN)
@@ -111,6 +120,8 @@ class NormalizeAssignments(ModelTransformer):
         for child in node.body:
             if not isinstance(child, Variable):
                 continue
+            if self.disablers.is_node_disabled(child):
+                continue
             var_token = child.get_token(Token.VARIABLE)
             self.normalize_equal_sign(
                 var_token,
